pub fn input<K, B>(value: u64, key_id: Identifier) -> Box<Append<K, B>>where
K: Keychain,
B: ProofBuild,Expand description
Adds an input with the provided value and blinding key to the transaction being built.
pub fn input<K, B>(value: u64, key_id: Identifier) -> Box<Append<K, B>>where
K: Keychain,
B: ProofBuild,Adds an input with the provided value and blinding key to the transaction being built.